/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.apache.tools.ant;

import org.junit.After;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;
import org.junit.rules.ExpectedException;

/**
 * created 16-Mar-2006 12:25:12
 */

public class ExtendedTaskdefTest {

    @Rule
    public BuildFileRule buildRule = new BuildFileRule();

    @Rule
    public ExpectedException thrown = ExpectedException.none();

    @Before
    public void setUp() {
        buildRule.configureProject("src/etc/testcases/core/extended-taskdef.xml");
    }

    @After
    public void tearDown() {
        buildRule.executeTarget("teardown");
    }

    /**
     * Exception should be thrown by a subclass
     */
    @Test
    public void testRun() {
        thrown.expect(BuildException.class);
        thrown.expectMessage("executing the Foo task");
        buildRule.executeTarget("testRun");
    }

    /**
     * Exception should be thrown by a subclass
     */
    @Test
    public void testRun2() {
        thrown.expect(BuildException.class);
        thrown.expectMessage("executing the Foo task");
        buildRule.executeTarget("testRun2");
    }

}
